@@ -15,12 +15,20 @@ class IdGenerator(object):
     self.branch_id += 1
     return "%s%02d" % (self.parent_id, self.branch_id)
 
-def check_status(status_code):
-  if status_code != 200:
+def check_result(http_result):
+  if http_result.status_code != 200:
     raise Exception("bad result")
+  # print("http_result text is: ", http_result.text)
+  if http_result.text.find("FAILURE") != -1:
+    raise Exception("FAILURE")
+
 
 def gen_gid(dtm):
   r = requests.get(dtm + "/newGid")
-  check_status(r.status_code)
+  check_result(r)
   return r.json()["gid"]
 
+def sqlexec(cursor, sql):
+  affected = cursor.execute(sql)
+  print("affected %d for sql: %s" %(affected, sql))
+  return affected
